@@ -1,7 +1,7 @@
 """
 Implements an EYAML-capable version of YAML Path.
 
-Copyright 2018, 2019 William W. Kimball, Jr. MBA MSIS
+Copyright 2018, 2019, 2020 William W. Kimball, Jr. MBA MSIS
 """
 import re
 from subprocess import run, PIPE, CalledProcessError
@@ -20,34 +20,35 @@ from yamlpath import Processor
 
 
 class EYAMLProcessor(Processor):
-    """
-    Extend Processor to understand EYAML values.
+    """Extend Processor to understand EYAML values."""
 
-    Note that due to a bug in the eyaml command at the time of this writing,
-    either both or neither of the public and private keys must be set.  So,
-    even though you would normally need only the public key to encrypt values,
-    you must also supply the private key, anyway.
+    def __init__(self, logger: ConsolePrinter, data: Any,
+                 **kwargs: Optional[str]) -> None:
+        """
+        Instantiate an EYAMLProcessor.
 
-    Parameters:
+        Note that due to a bug in the eyaml command at the time of this
+        writing, either both or neither of the public and private keys must be
+        set.  So, even though you would normally need only the public key to
+        encrypt values, you must also supply the private key, anyway.
+
+        Parameters:
         1. logger (ConsolePrinter) Instance of ConsolePrinter or subclass
         2. data (Any) Parsed YAML data
         3. **kwargs (Optional[str]) can contain the following keyword
            parameters:
-           * binary (str) The external eyaml command to use when performing
-             data encryption or decryption; if no path is provided, the command
-             will be sought on the system PATH.  Defaut="eyaml"
-           * publickey (Optional[str]) Fully-qualified path to the public key
-             for use with data encryption
-           * privatekey (Optional[str]) Fully-qualified path to the public key
-             for use with data decryption
+            * binary (str) The external eyaml command to use when performing
+              data encryption or decryption; if no path is provided, the
+              command will be sought on the system PATH.  Defaut="eyaml"
+            * publickey (Optional[str]) Fully-qualified path to the public key
+              for use with data encryption
+            * privatekey (Optional[str]) Fully-qualified path to the public key
+              for use with data decryption
 
-    Returns:  N/A
+        Returns:  N/A
 
-    Raises:  N/A
-    """
-
-    def __init__(self, logger: ConsolePrinter, data: Any,
-                 **kwargs: Optional[str]) -> None:
+        Raises:  N/A
+        """
         self.eyaml: Optional[str] = kwargs.pop("binary", "eyaml")
         self.publickey: Optional[str] = kwargs.pop("publickey", None)
         self.privatekey: Optional[str] = kwargs.pop("privatekey", None)
@@ -58,6 +59,8 @@ class EYAMLProcessor(Processor):
             self, data: Any, build_path: str = ""
     ) -> Generator[YAMLPath, None, None]:
         """
+        Find every encrypted value and report each as a YAML Path.
+
         Recursively generates a set of stringified YAML Paths, each entry
         leading to an EYAML value within the evaluated YAML data.
 
@@ -98,8 +101,7 @@ class EYAMLProcessor(Processor):
 
     def find_eyaml_paths(self) -> Generator[YAMLPath, None, None]:
         """
-        Recursively generates a set of stringified YAML Paths, each entry
-        leading to an EYAML value within the evaluated YAML data.
+        Find every encrypted value and reports its YAML Path.
 
         Parameters:  N/A
 
@@ -114,10 +116,10 @@ class EYAMLProcessor(Processor):
 
     def decrypt_eyaml(self, value: str) -> str:
         """
-        Decrypts an EYAML value.
+        Decrypt an EYAML value.
 
         Parameters:
-            1. value (str) The EYAML value to decrypt
+        1. value (str) The EYAML value to decrypt
 
         Returns:  (str) The decrypted value or the original value if it was not
         actually encrypted.
@@ -146,11 +148,14 @@ class EYAMLProcessor(Processor):
         )
 
         try:
+            # self.eyaml is untrusted, so shell must always be False and
+            # all parameters must be supplied via a List.
             retval: str = run(
                 cmd,
                 stdout=PIPE,
                 input=bval,
-                check=True
+                check=True,
+                shell=False
             ).stdout.decode('ascii').rstrip()
         except CalledProcessError as ex:
             raise EYAMLCommandException(
@@ -175,11 +180,11 @@ class EYAMLProcessor(Processor):
                       output: EYAMLOutputFormats = EYAMLOutputFormats.STRING
                      ) -> str:
         """
-        Encrypts a value via EYAML.
+        Encrypt a value via EYAML.
 
         Parameters:
-            1. value (str) the value to encrypt
-            2. output (EYAMLOutputFormats) the output format of the encryption
+        1. value (str) the value to encrypt
+        2. output (EYAMLOutputFormats) the output format of the encryption
 
         Returns:  (str) The encrypted result or the original value if it was
         already an EYAML encryption.
@@ -210,8 +215,10 @@ class EYAMLProcessor(Processor):
         bval: bytes = (value + "\n").encode("ascii")
 
         try:
+            # self.eyaml is untrusted, so shell must always be False and
+            # all parameters must be supplied via a List.
             retval: str = (
-                run(cmd, stdout=PIPE, input=bval, check=True)
+                run(cmd, stdout=PIPE, input=bval, check=True, shell=False)
                 .stdout
                 .decode('ascii')
                 .rstrip()
@@ -241,16 +248,15 @@ class EYAMLProcessor(Processor):
                         output: EYAMLOutputFormats = EYAMLOutputFormats.STRING,
                         mustexist: bool = False) -> None:
         """
-        Encrypts a value and stores the result to zero or more nodes specified
-        via YAML Path.
+        Encrypt and store a value where specified via YAML Path.
 
         Parameters:
-            1. yaml_path (Path) The YAML Path specifying which nodes are to
-               receive the encrypted value
-            2. value (any) The value to encrypt
-            3. output (EYAMLOutputFormats) the output format of the encryption
-            4. mustexist (bool) Indicates whether YAML Path must
-                specify a pre-existing node
+        1. yaml_path (Path) The YAML Path specifying which nodes are to
+           receive the encrypted value
+        2. value (any) The value to encrypt
+        3. output (EYAMLOutputFormats) the output format of the encryption
+        4. mustexist (bool) Indicates whether YAML Path must
+           specify a pre-existing node
 
         Returns:  N/A
 
@@ -277,17 +283,16 @@ class EYAMLProcessor(Processor):
                          default_value: str = ""
                         ) -> Generator[str, None, None]:
         """
-        Retrieves and decrypts zero or more EYAML nodes from YAML data at a
-        YAML Path.
+        Retrieve and decrypt all EYAML nodes identified via a YAML Path.
 
         Parameters:
-            1. yaml_path (Path) The YAML Path specifying which nodes to decrypt
-            2. mustexist (bool) Indicates whether YAML Path must specify a
-               pre-existing node; when False, the node will be created when
-               missing
-            3. default_value (str) The default value to add to the YAML data
-               when `mustexist=False` and yaml_path points to a non-existent
-               node
+        1. yaml_path (Path) The YAML Path specifying which nodes to decrypt
+        2. mustexist (bool) Indicates whether YAML Path must specify a
+           pre-existing node; when False, the node will be created when
+           missing
+        3. default_value (str) The default value to add to the YAML data
+           when `mustexist=False` and yaml_path points to a non-existent
+           node
 
         Returns:  (str) The decrypted value or `default_value` when YAML Path
             specifies a non-existant node
@@ -305,8 +310,7 @@ class EYAMLProcessor(Processor):
 
     def _can_run_eyaml(self) -> bool:
         """
-        Indicates whether this instance is capable of running the eyaml binary
-        as specified via its eyaml property.
+        Indicate whether this instance is capable of running the eyaml binary.
 
         Parameters:  N/A
 
@@ -324,13 +328,14 @@ class EYAMLProcessor(Processor):
     @staticmethod
     def get_eyaml_executable(binary: Optional[str] = "eyaml") -> Optional[str]:
         """
-        Returns the full executable path to an eyaml binary or None when it
-        cannot be found or is not executable.
+        Return the full executable path to an eyaml binary.
+
+        Returns None when it cannot be found or is not executable.
 
         Parameters:
-            1. binary (str) The executable to test; if an absolute or relative
-               path is not provided, the system PATH will be searched for a
-               match to test
+        1. binary (str) The executable to test; if an absolute or relative
+           path is not provided, the system PATH will be searched for a
+           match to test
 
         Returns: (str) None or the executable eyaml binary path
 
@@ -352,10 +357,10 @@ class EYAMLProcessor(Processor):
     @staticmethod
     def is_eyaml_value(value: str) -> bool:
         """
-        Indicates whether a value is EYAML-encrypted.
+        Indicate whether a value is EYAML-encrypted.
 
         Parameters:
-            1. value (any) The value to check
+        1. value (any) The value to check
 
         Returns:  (bool) True when the value is encrypted; False, otherwise
 
